@@ -6,24 +6,45 @@ from datamaps.api import project_data_from_master
 from docx.enum.section import WD_SECTION_START
 
 from analysis_engine.data import (
-    root_path,
+    # root_path,
     open_word_doc,
-    get_project_information,
+    # get_project_information,
     wd_heading,
     compare_text_new_and_old,
 )
 
+from analysis_engine.core_data import get_project_information
+
 from docx import Document
 
 
+def get_gmpp_ar_data(
+    confi_path: Path,
+) -> Dict:
+    try:
+        config = configparser.ConfigParser()
+        config.read(confi_path)
+        path_dict = {
+            "gmpp_ar_master": config["GMPP ANNUAL REPORT"]["ar_master_data"],
+        }
+    except:
+        logger.critical(
+            "Configuration file issue. Please check and make sure it's correct."
+        )
+        sys.exit(1)
+
+    return path_dict
+
+
 def get_ar_data(file_name):
     return project_data_from_master(
-        root_path / 'core_data/{}.xlsx'.format(file_name), 4, 2021
+        root_path / "core_data/{}.xlsx".format(file_name), 4, 2021
     )
 
+
 def ar_run_p_reports(
-        data: dict,
-        # project_list: list,
+    data: dict,
+    # project_list: list,
 ) -> None:
     report_doc = open_word_doc(root_path / "input/summary_temp.docx")
 
@@ -90,16 +111,23 @@ def ar_narratives(
         v = data[project_name][headings_list[x]]
 
         if isinstance(v, date):
-            text_one = v.strftime('%d/%m/%Y')
+            text_one = v.strftime("%d/%m/%Y")
         else:
             text_one = str(v)
-        # try:
-        #     text_two = str(data[project_name][headings_list[x]])
-        # except (KeyError, IndexError):  # index error relates to data_bridge
+            # try:
+            #     text_two = str(data[project_name][headings_list[x]])
+            # except (KeyError, IndexError):  # index error relates to data_bridge
             text_two = text_one
 
-        if headings_list[x] == "Date of the latest approved HMT Treasury Approval point (sent to PAC)":
-            text_one = str(data[project_name]["Type of the latest-approved HMT TAP"]) + ": " + text_one
+        if (
+            headings_list[x]
+            == "Date of the latest approved HMT Treasury Approval point (sent to PAC)"
+        ):
+            text_one = (
+                str(data[project_name]["Type of the latest-approved HMT TAP"])
+                + ": "
+                + text_one
+            )
             text_two = text_one
 
         doc.add_paragraph().add_run(str(headings_list[x])).bold = True
