@@ -23,12 +23,16 @@ from analysis_engine.data import (
     dandelion_number_text,
     cal_group_angle,
     convert_rag_text,
-    Master,
+    # Master,
     logger,
     MilestoneData,
     milestone_info_handling,
-    wd_heading, convert_date, get_project_info_data,
+    wd_heading,
+    convert_date,
 )
+
+from analysis_engine.core_data import get_project_information
+
 import platform
 from pathlib import Path
 from docx import Document, table
@@ -52,7 +56,7 @@ def _top_35_platform_docs_dir() -> Path:
 top35_root_path = _top_35_platform_docs_dir()
 
 
-def top35_run_p_reports(master: Master, **kwargs) -> None:
+def top35_run_p_reports(master, **kwargs) -> None:
     group = get_group(master, str(master.current_quarter), kwargs)
     for p in group:
         p_name = master.project_information[p]["Abbreviations"]
@@ -100,20 +104,21 @@ def top35_run_p_reports(master: Master, **kwargs) -> None:
 
 def compile_p_report(
     doc: Document,
-    master: Master,
+    master,
     project_name: str,
     **kwargs,
 ) -> Document:
     # p_master = master.master_data[0].data[project_name]
+    kwargs["group"] = [project_name]
     r_args = [doc, master, project_name]
-    wd_heading(doc, master.project_information, project_name)
+    wd_heading(doc, **kwargs)
     key_contacts(*r_args)
     project_scope_text(*r_args)
     deliverables(*r_args)
     project_report_meta_data(*r_args)
     # doc.add_section(WD_SECTION_START.NEW_PAGE)
     dca_narratives(*r_args)
-    kwargs["group"] = [project_name]
+    # kwargs["group"] = [project_name]
     ms = MilestoneData(master, "ipdc_milestones", **kwargs)  # milestones
     print_out_project_milestones(doc, ms)
     cs = CentralSupportData(master, **kwargs)  # central support
@@ -156,17 +161,17 @@ def key_contacts(doc: Document, master: Dict, project_name: str) -> None:
     doc.add_paragraph("SRO: " + str(sro_name) + ", " + str(sro_email))
 
 
-def project_scope_text(doc: Document, master: Master, project_name: str) -> Document:
+def project_scope_text(doc: Document, master, project_name: str) -> Document:
     doc.add_paragraph().add_run("Short project description").bold = True
     text_one = str(
         master.master_data[0]["data"][project_name]["SHORT PROJECT DESCRIPTION"]
     )
-    # try:
-    text_two = str(
-        master.master_data[1]["data"][project_name]["SHORT PROJECT DESCRIPTION"]
-    )
-    # except IndexError:
-    #     text_two = text_one
+    try:
+        text_two = str(
+            master.master_data[1]["data"][project_name]["SHORT PROJECT DESCRIPTION"]
+        )
+    except KeyError:
+        text_two = text_one
     compare_text_new_and_old(text_one, text_two, doc)
     return doc
 
@@ -181,11 +186,15 @@ def deliverables(doc: Document, master: Dict, project_name: str) -> Document:
     doc.add_paragraph().add_run("Top 3 Deliverables").bold = True
 
     for i, d in enumerate(dels):
-        try:  # this is necessary as string data contains NBSP and this removes them
-            text_one = master.master_data[0]["data"][project_name][d]
+        text_one = master.master_data[0]["data"][project_name][d]
+        try:
             text_two = master.master_data[1]["data"][project_name][d]
+        except KeyError:
+            text_two = text_one
+
+        try:
             compare_text_new_and_old(text_one, text_two, doc)
-        except AttributeError:
+        except AttributeError:  # this is necessary as string data contains NBSP and this removes them
             pass
 
     return doc
@@ -216,7 +225,11 @@ def project_report_meta_data(
     project_name: str,
 ):
     p_master = master.master_data[0]["data"][project_name]
-    p_master_last = master.master_data[1]["data"][project_name]
+    try:
+        p_master_last = master.master_data[1]["data"][project_name]
+    except KeyError:
+        p_master_last = p_master
+
     """Meta data table"""
     # doc.add_section(WD_SECTION_START.NEW_PAGE)
     # paragraph = doc.add_paragraph()
@@ -259,9 +272,20 @@ def project_report_meta_data(
         total_last = dandelion_number_text(p_master_last["WLC TOTAL"])
     else:
         total = dandelion_number_text(p_master["WLC TOTAL"] + p_master["WLC NON GOV"])
-        total_last = dandelion_number_text(p_master_last["WLC TOTAL"] + p_master_last["WLC NON GOV"])
+        total_last = dandelion_number_text(
+            p_master_last["WLC TOTAL"] + p_master_last["WLC NON GOV"]
+        )
     row_cells[3].text = total
     make_text_red(row_cells[3], total, total_last)
+    row_cells = t.add_row().cells
+    row_cells[0].text = "COVID IMPACT:"
+    c_impact = str(p_master["COVID IMPACT"])
+    try:
+        c_impact_last = str(p_master_last["COVID IMPACT"])
+    except KeyError:
+        c_impact_last = c_impact
+    row_cells[1].text = c_impact
+    make_text_red(row_cells[1], c_impact, c_impact_last)
     # row_cells = t.add_row().cells
     # row_cells[0].text = "SRO CLEARANCE DATE:"
     # row_cells[1].text = str(p_master["DATE CLEARED BY SRO"])
@@ -281,25 +305,56 @@ def project_report_meta_data(
 
 def dca_narratives(doc: Document, master: Dict, project_name: str) -> None:
     doc.add_paragraph()
-    # p = doc.add_paragraph()
-    # text = "*Red text highlights changes in narratives from last quarter"
-    # p.add_run(text).font.color.rgb = RGBColor(255, 0, 0)
 
     narrative_keys_list = [
         "SRO YOUR ON OFF TRACK ASSESSMENT:",
         "PRIMARY CONCERN & MITIGATING ACTIONS",
         "SHORT UPDATE FOR PM NOTE",
+        ["IMPACT ON MILESTONES", "COVID CONTINGENCY PLANS"],
+        ["CONTRIBUTION TO LEVELLING UP", "CHALLENGES TO LEVELLING UP"],
     ]
 
     headings_list = [
         "SRO assessment narrative",
         "SRO single biggest concern",
         "Short update for PM",
+        "Impact and Mitigation to COVID19",
+        "Leveling-up aims and challenges",
     ]
 
-    for x in range(len(headings_list)):
-        text_one = str(master.master_data[0]["data"][project_name][narrative_keys_list[x]])
-        text_two = str(master.master_data[1]["data"][project_name][narrative_keys_list[x]])
+    for x, heading in enumerate(narrative_keys_list):
+        if type(heading) == list:
+            li_one_text_one = str(
+                master.master_data[0]["data"][project_name][narrative_keys_list[x][0]]
+            )
+            li_two_text_one = str(
+                master.master_data[0]["data"][project_name][narrative_keys_list[x][1]]
+            )
+            text_one = li_one_text_one + li_two_text_one
+            try:
+                li_one_text_two = str(
+                    master.master_data[1]["data"][project_name][
+                        narrative_keys_list[x][0]
+                    ]
+                )
+                li_two_text_two = str(
+                    master.master_data[1]["data"][project_name][
+                        narrative_keys_list[x][1]
+                    ]
+                )
+                text_two = li_one_text_two + li_two_text_two
+            except KeyError:
+                text_two = text_one
+        else:
+            text_one = str(
+                master.master_data[0]["data"][project_name][narrative_keys_list[x]]
+            )
+            try:
+                text_two = str(
+                    master.master_data[1]["data"][project_name][narrative_keys_list[x]]
+                )
+            except KeyError:
+                text_two = text_one
         doc.add_paragraph().add_run(str(headings_list[x])).bold = True
         compare_text_new_and_old(text_one, text_two, doc)
 
@@ -359,6 +414,7 @@ def dca_narratives(doc: Document, master: Dict, project_name: str) -> None:
 #             pass
 #
 
+
 def cs_info_handling(output_list: list, t_list: list) -> list:
     """helper function for handling and cleaning up milestone date generated
     via MilestoneDate class. Removes none type milestone names and non date
@@ -372,7 +428,7 @@ def cs_info_handling(output_list: list, t_list: list) -> list:
 class CentralSupportData:
     def __init__(
         self,
-        master: Master,
+        master,
         # baseline_type: str = "ipdc_milestones",
         **kwargs,
     ):
@@ -400,12 +456,12 @@ class CentralSupportData:
         sp_dict = {}
         self.iter_list = get_iter_list(self.kwargs, self.master)
         for tp in self.iter_list:  # tp time period
+            self.kwargs["tp"] = tp
             lower_dict = {}
             raw_list = []
             self.group = get_group(self.master, tp, self.kwargs)
             for project_name in self.group:
                 project_list = []
-                # p_data = self.master.master_data[0]["data"][project_name]
                 p_data = get_correct_p_data(
                     self.kwargs, self.master, self.baseline_type, project_name, tp
                 )
@@ -415,7 +471,7 @@ class CentralSupportData:
                 p = self.master.abbreviations[project_name]["abb"]
                 report = "Top 250"
                 category = "Central Resource"
-                for i in range(1, 30):
+                for i in range(1, 17):
                     # these keys not present in all monthly masters.
                     try:
                         cs_response = p_data["R" + str(i) + " Central Response"]
@@ -444,18 +500,7 @@ class CentralSupportData:
                         ("Report", report),
                         ("Cat", category),
                     ]
-                    milestone_info_handling(project_list, t, type="central support")
-                # for i in range(17, 20):
-                #     t = [
-                #         ("Project", p),
-                #         ("Requirement", p_data["R" + str(i) + " name"]),
-                #         ("Escalated", p_data["R" + str(i) + " escalated to"]),
-                #         ("Date", convert_date(p_data["R" + str(i) + " needed by"])),
-                #         ("Type", p_data["R" + str(i) + " type"]),
-                #         ("Report", report),
-                #         ("Cat", category),
-                #     ]
-                #     milestone_info_handling(project_list, t, type="central support")
+                    milestone_info_handling(project_list, t, **self.kwargs)
 
                 # loop to stop keys names being the same. Done at project level.
                 # not particularly concise code.
@@ -471,7 +516,7 @@ class CentralSupportData:
                         new_require_key = (
                             entry[1][1] + " (" + str(lower_count[entry[1][1]]) + ")"
                         )
-                        entry[1] = ("Milestone", new_require_key)
+                        entry[1] = ("Requirement", new_require_key)
                         raw_list.append(entry)
                     else:
                         raw_list.append(entry)
@@ -771,17 +816,16 @@ def print_out_project_milestones(
     # ab = milestones.master.abbreviations[project_name]["abb"]
     doc.add_paragraph().add_run("Milestones").bold = True
 
-    table = doc.add_table(rows=1, cols=4)
-    hdr_cells = table.rows[0].cells
-    hdr_cells[0].text = "Milestone"
-    hdr_cells[1].text = "Date"
-    hdr_cells[2].text = "Status"
-    # hdr_cells[3].text = "Change from baseline"
-    hdr_cells[3].text = "Notes"
-
     if not milestones.sorted_milestone_dict[milestones.iter_list[0]]["names"]:
         doc.add_paragraph().add_run("No milestones reported")
     else:
+        table = doc.add_table(rows=1, cols=4)
+        hdr_cells = table.rows[0].cells
+        hdr_cells[0].text = "Milestone"
+        hdr_cells[1].text = "Date"
+        hdr_cells[2].text = "Status"
+        # hdr_cells[3].text = "Change from baseline"
+        hdr_cells[3].text = "Notes"
         for i, m in enumerate(
             milestones.sorted_milestone_dict[milestones.iter_list[0]]["names"]
         ):
@@ -793,32 +837,6 @@ def print_out_project_milestones(
             row_cells[2].text = milestones.sorted_milestone_dict[
                 milestones.iter_list[0]
             ]["status"][i]
-            # try:
-            #     row_cells[2].text = plus_minus_days(
-            #         (
-            #                 milestones.sorted_milestone_dict[milestones.iter_list[0]][
-            #                     "r_dates"
-            #                 ][i]
-            #                 - milestones.sorted_milestone_dict[milestones.iter_list[1]][
-            #                     "r_dates"
-            #                 ][i]
-            #         ).days
-            #     )
-            # except TypeError:
-            #     row_cells[2].text = "Not reported"
-            # try:
-            #     row_cells[3].text = plus_minus_days(
-            #         (
-            #                 milestones.sorted_milestone_dict[milestones.iter_list[0]][
-            #                     "r_dates"
-            #                 ][i]
-            #                 - milestones.sorted_milestone_dict[milestones.iter_list[2]][
-            #                     "r_dates"
-            #                 ][i]
-            #         ).days
-            #     )
-            # except TypeError:
-            #     row_cells[3].text = "Not reported"
             try:
                 row_cells[3].text = milestones.sorted_milestone_dict[
                     milestones.iter_list[0]
@@ -861,10 +879,12 @@ def print_out_central_support(
         hdr_cells[1].text = "Need by"
         hdr_cells[2].text = "Escalated to"
         hdr_cells[3].text = "Type"
-        hdr_cells[4].text = "Central Response"
-        hdr_cells[5].text = "Secured"
+        hdr_cells[4].text = "Type - other"
+        hdr_cells[5].text = "Further details"
 
-        for i, m in enumerate(centrals.sorted_milestone_dict[centrals.iter_list[0]]["names"]):
+        for i, m in enumerate(
+            centrals.sorted_milestone_dict[centrals.iter_list[0]]["names"]
+        ):
             row_cells = table.add_row().cells
             row_cells[0].text = m
             paragraph = row_cells[0].paragraphs[0]
@@ -872,9 +892,9 @@ def print_out_central_support(
             font = run[0].font
             font.size = Pt(8)  # font size = 8
             try:
-                row_cells[1].text = centrals.sorted_milestone_dict[centrals.iter_list[0]][
-                    "r_dates"
-                ][i].strftime("%d/%m/%Y")
+                row_cells[1].text = centrals.sorted_milestone_dict[
+                    centrals.iter_list[0]
+                ]["r_dates"][i].strftime("%d/%m/%Y")
                 paragraph = row_cells[1].paragraphs[0]
                 run = paragraph.runs
                 font = run[0].font
